@@ -2,16 +2,19 @@
 
 /**
   * SquirrelMail Virtual Host Login Plugin
-  * Copyright (C) 2003, 2004 Paul Lesneiwski <pdontthink@angrynerds.com>
-  * This program is licensed under GPL. See COPYING for details
+  * Copyright (c) 2003-2005 Paul Lesneiwski <pdontthink@angrynerds.com>
+  * Licensed under the GNU GPL. For full terms see the file COPYING.
+  *
+  * @package plugins
+  * @subpackage vlogin
   *
   */
 
 
-if (!defined('SM_PATH'))
-   define('SM_PATH', '../');
-
-
+/**
+  * Register this plugin with SquirrelMail
+  *
+  */
 function squirrelmail_plugin_init_vlogin() {
 
   global $squirrelmail_plugin_hooks;
@@ -53,7 +56,7 @@ function squirrelmail_plugin_init_vlogin() {
   {
 
      include_once(SM_PATH . 'plugins/vlogin/functions.php');
-     overrideSmConfig();
+     overrideSmConfig(array('squirrelmail_plugin_init_vlogin')); // dummy hook name
 
   }
 
@@ -61,15 +64,44 @@ function squirrelmail_plugin_init_vlogin() {
 }
 
 
-function vlogin_domain() 
+
+/** @ignore */
+if (!defined('SM_PATH'))
+   define('SM_PATH', '../');
+
+
+
+/**
+  * Returns version info about this plugin
+  *
+  */
+function vlogin_version() 
 {
 
-   include_once(SM_PATH . 'plugins/vlogin/functions.php');
-   vlogin_domain_do();
+   return '3.8.0-1.2.7';
 
 }
 
 
+
+/**
+  * Remap Username When Logging In
+  *
+  */
+function vlogin_domain($args) 
+{
+
+   include_once(SM_PATH . 'plugins/vlogin/functions.php');
+   vlogin_domain_do($args);
+
+}
+
+
+
+/**
+  * Allows control over which options are displayed on options pages
+  *
+  */
 function vlogin_display_options() 
 {
 
@@ -79,20 +111,18 @@ function vlogin_display_options()
 }
 
 
-function vlogin_overrideSmConfig() 
+
+/**
+  * Override Default Config Values
+  *
+  */
+function vlogin_overrideSmConfig($args) 
 {
 
    include_once(SM_PATH . 'plugins/vlogin/functions.php');
-   overrideSmConfig();
+   overrideSmConfig($args);
 
 }
 
 
-function vlogin_version() 
-{
-
-   return '3.6';
-
-}
-
 ?>
